@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use OptArgs;
 use lib 'lib';
-our $VERSION = '0.0.2';
+our $VERSION = '0.0.3';
 
 $OptArgs::COLOUR = 1;
 
@@ -16,7 +16,7 @@ arg class => (
 arg name => (
     isa     => 'Str',
     comment => 'Name of the command',
-    default => sub { return shift->{class}; }
+    default => sub { ( my $x = shift->{class} ) =~ s/.*://; $x; }
 );
 
 opt indent => (
@@ -44,13 +44,14 @@ sub run {
 
     die $@ unless eval "require $opts->{class};";
 
-    my $initial = scalar split( /::/, $opts->{class} );
+    my $initial = do { my @tmp = split( /::/, $opts->{class} ) };
     my $indent = $opts->{spacer} x $opts->{indent};
 
     binmode( STDOUT, ':encoding(utf8)' );
 
     foreach my $cmd ( OptArgs::_cmdlist( $opts->{class} ) ) {
-        my $length = scalar split( /::/, $cmd ) - $initial;
+        my $length = do { my @tmp = split( /::/, $cmd ) }
+          - $initial;
         my $space = $indent x $length;
 
         unless ( $opts->{full} ) {
@@ -83,7 +84,7 @@ App::optargs - implementation of the optargs(1) command
 
 =head1 VERSION
 
-0.0.2 Development release.
+0.0.3 Development release.
 
 =head1 SYNOPSIS
 
