@@ -10,7 +10,7 @@ use Getopt::Long qw/GetOptionsFromArray/;
 use I18N::Langinfo qw/langinfo/;
 use List::Util qw/max/;
 
-our $VERSION = '0.0.2';
+our $VERSION = '0.0.3';
 our $COLOUR  = 0;
 
 my %seen;           # hash of hashes keyed by 'caller', then opt/arg name
@@ -19,6 +19,7 @@ my %args;           # argument configuration keyed by 'caller'
 my %caller;         # current 'caller' keyed by real caller
 my %desc;           # sub-command descriptions
 my %dispatching;    # track optargs() calls from dispatch classes
+my %hidden;         # subcmd hiding by default
 
 # internal method for App::optargs
 sub _cmdlist {
@@ -43,30 +44,60 @@ sub _cmdlist {
 }
 
 # ------------------------------------------------------------------------
-# Sub-commands work by faking caller context in opt() and arg()
+# Sub-command definition
+#
+# This works by faking caller context in opt() and arg()
 # ------------------------------------------------------------------------
+my %subcmd_params = (
+    cmd     => undef,
+    comment => undef,
+    hidden  => undef,
+
+    #    alias   => '',
+    #    ishelp  => undef,
+);
+
+my @subcmd_required = (qw/cmd comment/);
+
 sub subcmd {
+    my $params = {@_};
     my $caller = caller;
-    croak 'subcmd(@cmd,$description)' unless @_ >= 2;
 
-    my $desc = pop;
-    my $name = pop;
+    if ( my @missing = grep { !exists $params->{$_} } @subcmd_required ) {
+        croak "missing required parameter(s): @missing";
+    }
 
-    my $parent = join( '::', $caller, @_ );
+    if ( my @invalid = grep { !exists $subcmd_params{$_} } keys %$params ) {
+        my @valid = keys %subcmd_params;
+        croak "invalid parameter(s): @invalid (valid: @valid)";
+    }
+
+    #    croak "'ishelp' can only be applied to Bool opts"
+    #      if $params->{ishelp} and $params->{isa} ne 'Bool';
+
+    my @cmd =
+      ref $params->{cmd} eq 'ARRAY'
+      ? @{ $params->{cmd} }
+      : ( $params->{cmd} );
+    croak 'missing cmd elements' unless @cmd;
+
+    my $name = pop @cmd;
+    my $parent = join( '::', $caller, @cmd );
     $parent =~ s/-/_/g;
 
-    croak "parent command not found: @_" unless $seen{$parent};
+    croak "parent command not found: @cmd" unless $seen{$parent};
 
     my $package = $parent . '::' . $name;
     $package =~ s/-/_/g;
 
-    croak "sub command already defined: @_ $name" if $seen{$package};
+    croak "sub command already defined: @cmd $name" if $seen{$package};
 
-    $caller{$caller} = $package;
-    $desc{$package}  = $desc;
-    $seen{$package}  = {};
-    $opts{$package}  = [];
-    $args{$package}  = [];
+    $caller{$caller}  = $package;
+    $desc{$package}   = $params->{comment};
+    $seen{$package}   = {};
+    $opts{$package}   = [];
+    $args{$package}   = [];
+    $hidden{$package} = $params->{hidden};
 
     my $parent_arg = ( grep { $_->{isa} eq 'SubCmd' } @{ $args{$parent} } )[0];
     push( @{ $parent_arg->{subcommands} }, $name );
@@ -126,7 +157,7 @@ sub opt {
     $params->{package} = $package;
     $params->{name}    = $name;
     $params->{length}  = length $name;
-    $params->{acount}  = scalar split( '|', $params->{alias} );
+    $params->{acount}  = do { my @tmp = split( '|', $params->{alias} ) };
     $params->{type}    = 'opt';
     $params->{ISA}     = $params->{name};
 
@@ -260,6 +291,7 @@ sub _usage {
             foreach my $subcommand ( @{ $last->{subcommands} } ) {
                 my $pkg = $last->{package} . '::' . $subcommand;
                 $pkg =~ s/-/_/g;
+                next if $hidden{$pkg} and !$ishelp;
                 push( @usage, [ $me . ' ' . $subcommand, $desc{$pkg} ] );
             }
 
